@@ -287,7 +287,7 @@ class DeployBitSalesforce:
             query_result=process_query_response(search_response,'searchResponse',is_tooling_api)
             return query_result
         
-    def apex_execute(this,code_chunk):
+    def apex_execute(this,code_chunk,log_category='Apex_code',log_category_level='DEBUG'):
         if all((arg is None or arg=='') for arg in (this.session_id,this.instance_url)):
             raise DeployBitLoginError('Please call login() method before calling apex_execute()')
         elif code_chunk is None and code_chunk!='':
@@ -297,7 +297,9 @@ class DeployBitSalesforce:
             
             apex_execute_payload_attributes = {
                                                 'sessionId': this.session_id,
-                                                'codeChunk':escape(code_chunk)
+                                                'codeChunk':escape(code_chunk),
+                                                'logCategory':log_category,
+                                                'logCategoryLevel':log_category_level
                                             }
             apex_execute_request = APEX_EXECUTE_PAYLOAD.format(**apex_execute_payload_attributes)
             REQUEST_HEADERS['SOAPAction']='executeAnonymous'
